@@ -2,7 +2,7 @@ from os import getpid
 from logging import getLogger
 from .utils import func_logger, format_hctl, ScsiCommandFailed
 from .scsi import scsi_host_scan, scsi_add_single_device, remove_device_via_sysfs
-from .scsi import do_report_luns, do_standard_inquiry, do_test_unit_ready, Process
+from .scsi import do_report_luns, do_standard_inquiry, do_test_unit_ready
 from .getters import get_scsi_generic_device
 from .getters import get_hosts, get_channels, get_targets, get_luns
 from .getters import is_there_a_bug_in_target_removal, is_there_a_bug_in_sysfs_async_scanning
@@ -101,6 +101,7 @@ def try_target_scan(host, channel, target):
 
 @func_logger
 def rescan_scsi_host(host):
+    from infi.storagemodel.base.gevent_wrapper import start_process
     channels = get_channels(host)
     subprocesses = []
     if not is_there_a_bug_in_sysfs_async_scanning():
@@ -109,7 +110,7 @@ def rescan_scsi_host(host):
     for channel in channels:
         targets = get_targets(host, channel)
         for target in targets:
-            subprocesses.extend([Process(target=try_target_scan, args=(host, channel, target))])
+            subprocesses.append(start_process(try_target_scan, host, channel, target))
     return subprocesses
 
 @func_logger
